@@ -12,6 +12,7 @@ Functions:
 
 Classes:
 
+* :attr:`AlphaOmegaRawIO`
 * :attr:`AxographRawIO`
 * :attr:`AxonaRawIO`
 * :attr:`AxonRawIO`
@@ -19,6 +20,7 @@ Classes:
 * :attr:`BlackrockRawIO`
 * :attr:`BrainVisionRawIO`
 * :attr:`CedRawIO`
+* :attr: `EDFRawIO`
 * :attr:`ElanRawIO`
 * :attr:`IntanRawIO`
 * :attr:`MaxwellRawIO`
@@ -30,7 +32,7 @@ Classes:
 * :attr:`NIXRawIO`
 * :attr:`OpenEphysRawIO`
 * :attr:`OpenEphysBinaryRawIO`
-* :attr:'PhyRawIO'
+* :attr:`PhyRawIO`
 * :attr:`PlexonRawIO`
 * :attr:`RawBinarySignalRawIO`
 * :attr:`RawMCSRawIO`
@@ -42,6 +44,10 @@ Classes:
 * :attr:`WinWcpRawIO`
 
 
+.. autoclass:: neo.rawio.AlphaOmegaRawIO
+
+    .. autoattribute:: extensions
+
 .. autoclass:: neo.rawio.AxographRawIO
 
     .. autoattribute:: extensions
@@ -70,6 +76,10 @@ Classes:
 
     .. autoattribute:: extensions
 
+.. autoclass:: neo.rawio.EDFRawIO
+
+    .. autoattribute:: extensions
+
 .. autoclass:: neo.rawio.ElanRawIO
 
     .. autoattribute:: extensions
@@ -157,6 +167,7 @@ Classes:
 """
 import os
 
+from neo.rawio.alphaomegarawio import AlphaOmegaRawIO
 from neo.rawio.axographrawio import AxographRawIO
 from neo.rawio.axonarawio import AxonaRawIO
 from neo.rawio.axonrawio import AxonRawIO
@@ -164,6 +175,7 @@ from neo.rawio.biocamrawio import BiocamRawIO
 from neo.rawio.blackrockrawio import BlackrockRawIO
 from neo.rawio.brainvisionrawio import BrainVisionRawIO
 from neo.rawio.cedrawio import CedRawIO
+from neo.rawio.edfrawio import EDFRawIO
 from neo.rawio.elanrawio import ElanRawIO
 from neo.rawio.examplerawio import ExampleRawIO
 from neo.rawio.intanrawio import IntanRawIO
@@ -188,6 +200,7 @@ from neo.rawio.winedrrawio import WinEdrRawIO
 from neo.rawio.winwcprawio import WinWcpRawIO
 
 rawiolist = [
+    AlphaOmegaRawIO,
     AxographRawIO,
     AxonaRawIO,
     AxonRawIO,
@@ -195,6 +208,7 @@ rawiolist = [
     BlackrockRawIO,
     BrainVisionRawIO,
     CedRawIO,
+    EDFRawIO,
     ElanRawIO,
     IntanRawIO,
     MicromedRawIO,
