@@ -66,6 +66,7 @@ class OpenEphysBinaryRawIO(BaseRawIO):
         self.experiment_names = experiment_names
         self.load_sync_channel = load_sync_channel
         self.folder_structure = None
+        self._use_direct_evt_timestamps = None
 
     def _source_name(self):
         return self.dirname
@@ -157,40 +158,77 @@ class OpenEphysBinaryRawIO(BaseRawIO):
         event_channels = []
         for stream_ind, stream_name in enumerate(event_stream_names):
             d = self._evt_streams[0][0][stream_ind]
-            event_channels.append((d['channel_name'], stream_ind, 'event'))
+            if 'states' in d:
+                evt_channel_type = "epoch"
+            else:
+                evt_channel_type = "event"
+            event_channels.append((d['channel_name'], d['channel_name'], evt_channel_type))
         event_channels = np.array(event_channels, dtype=_event_channel_dtype)
 
-        # create memmap
-        for stream_ind, stream_name in enumerate(event_stream_names):
-            # inject memmap loaded into main dict structure
-            d = self._evt_streams[0][0][stream_ind]
+        # create memmap for events
+        for block_index in range(nb_block):
+            for seg_index in range(nb_segment_per_block[block_index]):
+                for stream_index, d in self._evt_streams[block_index][seg_index].items():
+                    for name in _possible_event_stream_names:
+                        if name + '_npy' in d:
+                            data = np.load(d[name + '_npy'], mmap_mode='r')
+                            d[name] = data
 
-            for name in _possible_event_stream_names:
-                if name + '_npy' in d:
-                    data = np.load(d[name + '_npy'], mmap_mode='r')
-                    d[name] = data
+                    # check that events have timestamps
+                    assert 'timestamps' in d, "Event stream does not have timestamps!"
+                    # Updates for OpenEphys v0.6:
+                    # In new vesion (>=0.6) timestamps.npy is now called sample_numbers.npy
+                    # The timestamps are already in seconds, so that event times don't require scaling
+                    # see https://open-ephys.github.io/gui-docs/User-Manual/Recording-data/Binary-format.html#events
+                    if 'sample_numbers' in d:
+                        self._use_direct_evt_timestamps = True
+                    else:
+                        self._use_direct_evt_timestamps = False
 
-            # check that events have timestamps
-            assert 'timestamps' in d
+                    # for event the neo "label" will change depending the nature
+                    #  of event (ttl, text, binary)
+                    # and this is transform into unicode
+                    # all theses data are put in event array annotations
+                    if 'text' in d:
+                        # text case
+                        d['labels'] = d['text'].astype('U')
+                    elif 'metadata' in d:
+                        # binary case
+                        d['labels'] = d['channels'].astype('U')
+                    elif 'channels' in d:
+                        # ttl case use channels
+                        d['labels'] = d['channels'].astype('U')
+                    elif 'states' in d:
+                        # ttl case use states
+                        d['labels'] = d['states'].astype('U')
+                    else:
+                        raise ValueError(f'There is no possible labels for this event: {stream_name}')
 
-            # for event the neo "label" will change depending the nature
-            #  of event (ttl, text, binary)
-            # and this is transform into unicode
-            # all theses data are put in event array annotations
-            if 'text' in d:
-                # text case
-                d['labels'] = d['text'].astype('U')
-            elif 'metadata' in d:
-                # binary case
-                d['labels'] = d['channels'].astype('U')
-            elif 'channels' in d:
-                # ttl case use channels
-                d['labels'] = d['channels'].astype('U')
-            elif 'states' in d:
-                # ttl case use states
-                d['labels'] = d['states'].astype('U')
-            else:
-                raise ValueError(f'There is no possible labels for this event: {stream_name}')
+                    # # If available, use 'states' to compute event duration
+                    if 'states' in d:
+                        states = d["states"]
+                        timestamps = d["timestamps"]
+                        labels = d["labels"]
+                        rising = np.where(states > 0)[0]
+                        falling = np.where(states < 0)[0]
+                        # make sure first event is rising and last is falling
+                        if states[0] < 0:
+                            falling = falling[1:]
+                        if states[-1] > 0:
+                            rising = rising[:-1]
+
+                        if len(rising) == len(falling):
+                            durations = timestamps[falling] - timestamps[rising]
+                        else:
+                            # something wrong if we get here
+                            durations = None
+
+                        d["rising"] = rising
+                        d["timestamps"] = timestamps[rising]
+                        d["labels"] = labels[rising]
+                        d["durations"] = durations
+                    else:
+                        d["durations"] = None
 
         # no spike read yet
         # can be implemented on user demand
@@ -218,11 +256,16 @@ class OpenEphysBinaryRawIO(BaseRawIO):
 
                 # loop over events
                 for stream_index, stream_name in enumerate(event_stream_names):
-                    d = self._evt_streams[0][0][stream_index]
+                    d = self._evt_streams[block_index][seg_index][stream_index]
                     if d['timestamps'].size == 0:
                         continue
-                    t_start = d['timestamps'][0] / d['sample_rate']
-                    t_stop = d['timestamps'][-1] / d['sample_rate']
+                    t_start = d['timestamps'][0]
+                    t_stop = d['timestamps'][-1]
+
+                    if not self._use_direct_evt_timestamps:
+                        t_start /= d['sample_rate']
+                        t_stop /= d['sample_rate']
+
                     if global_t_start is None or global_t_start > t_start:
                         global_t_start = t_start
                     if global_t_stop is None or global_t_stop < t_stop:
@@ -262,16 +305,26 @@ class OpenEphysBinaryRawIO(BaseRawIO):
                 for stream_index, stream_name in enumerate(event_stream_names):
                     ev_ann = seg_ann['events'][stream_index]
                     d = self._evt_streams[0][0][stream_index]
+                    if 'rising' in d:
+                        selected_indices = d["rising"]
+                    else:
+                        selected_indices = None
                     for k in _possible_event_stream_names:
-                        if k in ('timestamps', ):
+                        if k in ('timestamps', 'rising'):
                             continue
                         if k in d:
                             # split custom dtypes into separate annotations
                             if d[k].dtype.names:
                                 for name in d[k].dtype.names:
-                                    ev_ann['__array_annotations__'][name] = d[k][name].flatten()
+                                    arr_ann = d[k][name].flatten()
+                                    if selected_indices is not None:
+                                        arr_ann = arr_ann[selected_indices]
+                                    ev_ann['__array_annotations__'][name] = arr_ann
                             else:
-                                ev_ann['__array_annotations__'][k] = d[k]
+                                arr_ann = d[k]
+                                if selected_indices is not None:
+                                    arr_ann = arr_ann[selected_indices]
+                                ev_ann['__array_annotations__'][k] = arr_ann
 
     def _segment_t_start(self, block_index, seg_index):
         return self._t_start_segments[block_index][seg_index]
@@ -317,38 +370,53 @@ class OpenEphysBinaryRawIO(BaseRawIO):
         pass
 
     def _event_count(self, block_index, seg_index, event_channel_index):
-        d = self._evt_streams[0][0][event_channel_index]
-        return d['timestamps'].size
+        timestamps, _, _ = self._get_event_timestamps(block_index, seg_index, event_channel_index,
+                                                      None, None)
+        return timestamps.size
 
     def _get_event_timestamps(self, block_index, seg_index, event_channel_index, t_start, t_stop):
-        d = self._evt_streams[0][0][event_channel_index]
+        d = self._evt_streams[block_index][seg_index][event_channel_index]
         timestamps = d['timestamps']
-        durations = None
+        durations = d["durations"]
         labels = d['labels']
 
         # slice it if needed
         if t_start is not None:
-            ind_start = int(t_start * d['sample_rate'])
-            mask = timestamps >= ind_start
+            if not self._use_direct_evt_timestamps:
+                ind_start = int(t_start * d['sample_rate'])
+                mask = timestamps >= ind_start
+            else:
+                mask = timestamps >= t_start
             timestamps = timestamps[mask]
             labels = labels[mask]
         if t_stop is not None:
-            ind_stop = int(t_stop * d['sample_rate'])
-            mask = timestamps < ind_stop
+            if not self._use_direct_evt_timestamps:
+                ind_stop = int(t_stop * d['sample_rate'])
+                mask = timestamps < ind_stop
+            else:
+                mask = timestamps < t_stop
             timestamps = timestamps[mask]
             labels = labels[mask]
         return timestamps, durations, labels
 
     def _rescale_event_timestamp(self, event_timestamps, dtype, event_channel_index):
         d = self._evt_streams[0][0][event_channel_index]
-        event_times = event_timestamps.astype(dtype) / float(d['sample_rate'])
+        if not self._use_direct_evt_timestamps:
+            event_times = event_timestamps.astype(dtype) / float(d['sample_rate'])
+        else:
+            event_times = event_timestamps.astype(dtype)
         return event_times
 
-    def _rescale_epoch_duration(self, raw_duration, dtype):
-        pass
+    def _rescale_epoch_duration(self, raw_duration, dtype, event_channel_index):
+        d = self._evt_streams[0][0][event_channel_index]
+        if not self._use_direct_evt_timestamps:
+            durations = raw_duration.astype(dtype) / float(d['sample_rate'])
+        else:
+            durations = raw_duration.astype(dtype)
+        return durations
 
 
-_possible_event_stream_names = ('timestamps', 'channels', 'text', 'states',
+_possible_event_stream_names = ('timestamps', 'sample_numbers', 'channels', 'text', 'states',
                                 'full_word', 'channel_states', 'data_array', 'metadata')
 
 
