@@ -9,8 +9,8 @@ Author: Samuel Garcia
 
 """
 
-from .baserawio import (BaseRawIO, _signal_channel_dtype, _unit_channel_dtype,
-                        _event_channel_dtype)
+from .baserawio import (BaseRawIO, _signal_channel_dtype, _signal_stream_dtype,
+                _spike_channel_dtype, _event_channel_dtype, _common_sig_characteristics)
 
 import numpy as np
 
@@ -56,7 +56,7 @@ class WinEdrRawIO(BaseRawIO):
                 DT *= .001
         self._sampling_rate = 1. / DT
 
-        sig_channels = []
+        signal_channels = []
         for c in range(header['NC']):
             YCF = float(header['YCF%d' % c].replace(',', '.'))
             YAG = float(header['YAG%d' % c].replace(',', '.'))
@@ -69,26 +69,36 @@ class WinEdrRawIO(BaseRawIO):
             units = header['YU%d' % c]
             gain = AD / (YCF * YAG * (ADCMAX + 1))
             offset = -YZ * gain
-            group_id = 0
-            sig_channels.append((name, chan_id, self._sampling_rate, 'int16',
-                                 units, gain, offset, group_id))
+            stream_id = '0'
+            signal_channels.append((name, str(chan_id), self._sampling_rate, 'int16',
+                                 units, gain, offset, stream_id))
 
-        sig_channels = np.array(sig_channels, dtype=_signal_channel_dtype)
+        signal_channels = np.array(signal_channels, dtype=_signal_channel_dtype)
+
+        characteristics = signal_channels[_common_sig_characteristics]
+        unique_characteristics = np.unique(characteristics)
+        signal_streams = []
+        for i in range(unique_characteristics.size):
+            mask = unique_characteristics[i] == characteristics
+            signal_channels['stream_id'][mask] = str(i)
+            signal_streams.append((f'stream {i}', str(i)))
+        signal_streams = np.array(signal_streams, dtype=_signal_stream_dtype)
 
         # No events
         event_channels = []
         event_channels = np.array(event_channels, dtype=_event_channel_dtype)
 
         # No spikes
-        unit_channels = []
-        unit_channels = np.array(unit_channels, dtype=_unit_channel_dtype)
+        spike_channels = []
+        spike_channels = np.array(spike_channels, dtype=_spike_channel_dtype)
 
         # fille into header dict
         self.header = {}
         self.header['nb_block'] = 1
         self.header['nb_segment'] = [1]
-        self.header['signal_channels'] = sig_channels
-        self.header['unit_channels'] = unit_channels
+        self.header['signal_streams'] = signal_streams
+        self.header['signal_channels'] = signal_channels
+        self.header['spike_channels'] = spike_channels
         self.header['event_channels'] = event_channels
 
         # insert some annotation at some place
@@ -101,20 +111,19 @@ class WinEdrRawIO(BaseRawIO):
         t_stop = self._raw_signals.shape[0] / self._sampling_rate
         return t_stop
 
-    def _get_signal_size(self, block_index, seg_index, channel_indexes):
+    def _get_signal_size(self, block_index, seg_index, stream_index):
         return self._raw_signals.shape[0]
 
-    def _get_signal_t_start(self, block_index, seg_index, channel_indexes):
+    def _get_signal_t_start(self, block_index, seg_index, stream_index):
         return 0.
 
-    def _get_analogsignal_chunk(self, block_index, seg_index, i_start, i_stop, channel_indexes):
-        # WARNING check if id or index for signals (in the old IO it was ids
-        # ~ raw_signals = self._raw_signals[slice(i_start, i_stop), channel_indexes]
+    def _get_analogsignal_chunk(self, block_index, seg_index, i_start, i_stop,
+                                stream_index, channel_indexes):
+        stream_id = self.header['signal_streams'][stream_index]['id']
+        global_channel_indexes, = np.nonzero(self.header['signal_channels']
+                                    ['stream_id'] == stream_id)
         if channel_indexes is None:
-            channel_indexes = np.arange(self.header['signal_channels'].size)
-
-        l = self.header['signal_channels']['id'].tolist()
-        channel_ids = [l.index(c) for c in channel_indexes]
-        raw_signals = self._raw_signals[slice(i_start, i_stop), channel_ids]
-
+            channel_indexes = slice(None)
+        global_channel_indexes = global_channel_indexes[channel_indexes]
+        raw_signals = self._raw_signals[slice(i_start, i_stop), global_channel_indexes]
         return raw_signals
