@@ -10,11 +10,12 @@ from neo.test.iotest.common_io_test import BaseTestIO
 
 class TestElanIO(BaseTestIO, unittest.TestCase, ):
     ioclass = ElanIO
-    files_to_test = ['File_elan_1.eeg']
-    files_to_download = ['File_elan_1.eeg',
-                         'File_elan_1.eeg.ent',
-                         'File_elan_1.eeg.pos',
-                         ]
+    entities_to_download = [
+        'elan'
+    ]
+    entities_to_test = [
+        'elan/File_elan_1.eeg',
+    ]
 
 
 if __name__ == "__main__":
