@@ -12,26 +12,14 @@ import numpy as np
 from neo.io.nestio import ColumnIO
 from neo.io.nestio import NestIO
 from neo.test.iotest.common_io_test import BaseTestIO
-from neo.test.iotest.tools import get_test_file_full_path
 
 
 class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
     ioclass = NestIO
-    files_to_test = []
-    files_to_download = ['0gid-1time-2gex-3Vm-1261-0.dat',
-                         '0gid-1time-2gex-1262-0.dat',
-                         '0gid-1time-2Vm-3gex-4gin-1260-0.dat',
-                         '0gid-1time-2Vm-3Iex-4Iin-1264-0.dat',
-                         '0gid-1time-2Vm-1259-0.dat',
-                         '0gid-1time-1256-0.gdf',
-                         '0gid-1time_in_steps-2Vm-1263-0.dat',
-                         '0gid-1time_in_steps-1258-0.gdf',
-                         '0time-1255-0.gdf',
-                         '0time_in_steps-1257-0.gdf',
-                         'brunel-delta-nest_mod.py',
-                         'N1-0gid-1time-2Vm-1265-0.dat',
-                         'N1-0time-1Vm-1266-0.dat',
-                         'N1-0Vm-1267-0.dat']
+    entities_to_download = [
+        'nest'
+    ]
+    entities_to_test = []
 
     def test_read_analogsignal(self):
         """
@@ -39,11 +27,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
         - with GIDs, with times as floats
         - with GIDs, with time as integer
         """
-
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-2gex-3Vm-1261-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-2gex-3Vm-1261-0.dat')
         r = NestIO(filenames=filename)
         r.read_analogsignal(gid=1, t_stop=1000. * pq.ms,
                             sampling_period=pq.ms, lazy=False,
@@ -54,10 +38,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
                        time_column_dat=1, value_columns_dat=2,
                        value_types='V_m')
 
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time_in_steps-2Vm-1263-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time_in_steps-2Vm-1263-0.dat')
         r = NestIO(filenames=filename)
         r.read_analogsignal(gid=1, t_stop=1000. * pq.ms,
                             time_unit=pq.CompoundUnit('0.1*ms'),
@@ -70,10 +51,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
                        time_column_dat=1, value_columns_dat=2,
                        value_types='V_m')
 
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-2Vm-1259-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-2Vm-1259-0.dat')
         r = NestIO(filenames=filename)
         r.read_analogsignal(gid=1, t_stop=1000. * pq.ms,
                             time_unit=pq.CompoundUnit('0.1*ms'),
@@ -92,11 +70,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
         from a file which does not contain unit IDs, but data for multiple
         units.
         """
-
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0time-1255-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0time-1255-0.gdf')
         r = NestIO(filenames=filename)
         with self.assertRaises(ValueError):
             r.read_analogsignal(t_stop=1000. * pq.ms, lazy=False,
@@ -111,12 +85,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
         """
         Tests if the function returns the correct values.
         """
-
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-2gex-3Vm-1261-0.dat',
-            directory=self.local_test_dir, clean=False)
-
+        filename = self.get_local_path('nest/0gid-1time-2gex-3Vm-1261-0.dat')
         id_to_test = 1
         r = NestIO(filenames=filename)
         seg = r.read_segment(gid_list=[id_to_test],
@@ -135,11 +104,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
         """
         Tests if signals are correctly stored in a segment.
         """
-
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-2gex-1262-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-2gex-1262-0.dat')
         r = NestIO(filenames=filename)
 
         id_list_to_test = range(1, 10)
@@ -164,11 +129,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
         """
         Tests if signals are correctly stored in a block.
         """
-
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-2gex-1262-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-2gex-1262-0.dat')
         r = NestIO(filenames=filename)
 
         id_list_to_test = range(1, 10)
@@ -190,11 +151,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
           specifying a value_unit
         - User specifies t_start < 1.*sampling_period
         """
-
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-2gex-1262-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-2gex-1262-0.dat')
         r = NestIO(filenames=filename)
         with self.assertRaises(ValueError):
             r.read_segment(t_stop=1000. * pq.ms, lazy=False,
@@ -217,10 +174,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
         """
         Test for correct t_start and t_stop values of AnalogSignalArrays.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-2gex-1262-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-2gex-1262-0.dat')
         r = NestIO(filenames=filename)
 
         t_start_targ = 450. * pq.ms
@@ -239,11 +193,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
         """
         Test for warning, when no time column id was provided.
         """
-
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-2gex-1262-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-2gex-1262-0.dat')
         r = NestIO(filenames=filename)
 
         t_start_targ = 450. * pq.ms
@@ -271,11 +221,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
         """
         Test for simultaneous loading of multiple columns from dat file.
         """
-
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-2Vm-3Iex-4Iin-1264-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-2Vm-3Iex-4Iin-1264-0.dat')
         r = NestIO(filenames=filename)
 
         sampling_period = pq.CompoundUnit('5*ms')
@@ -286,10 +232,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
         self.assertEqual(len(anasigs), 2)
 
     def test_single_gid(self):
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='N1-0gid-1time-2Vm-1265-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/N1-0gid-1time-2Vm-1265-0.dat')
         r = NestIO(filenames=filename)
         anasig = r.read_analogsignal(gid=1, t_stop=1000. * pq.ms,
                                      time_unit=pq.CompoundUnit('0.1*ms'),
@@ -299,10 +242,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
         assert anasig.annotations['id'] == 1
 
     def test_no_gid(self):
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='N1-0time-1Vm-1266-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/N1-0time-1Vm-1266-0.dat')
         r = NestIO(filenames=filename)
         anasig = r.read_analogsignal(gid=None, t_stop=1000. * pq.ms,
                                      time_unit=pq.CompoundUnit('0.1*ms'),
@@ -313,10 +253,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
         self.assertEqual(len(anasig), 19)
 
     def test_no_gid_no_time(self):
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='N1-0Vm-1267-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/N1-0Vm-1267-0.dat')
         r = NestIO(filenames=filename)
         anasig = r.read_analogsignal(gid=None,
                                      sampling_period=pq.ms, lazy=False,
@@ -328,8 +265,7 @@ class TestNestIO_Analogsignals(BaseTestIO, unittest.TestCase):
 
 class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
     ioclass = NestIO
-    files_to_test = []
-    files_to_download = []
+    entities_to_download = ['nest']
 
     def test_read_spiketrain(self):
         """
@@ -339,20 +275,14 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         - with GIDs, with times as floats
         - with GIDs, with times as integers in time steps
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0time-1255-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0time-1255-0.gdf')
         r = NestIO(filenames=filename)
         r.read_spiketrain(t_start=400. * pq.ms, t_stop=500. * pq.ms, lazy=False,
                           id_column=None, time_column=0)
         r.read_segment(t_start=400. * pq.ms, t_stop=500. * pq.ms, lazy=False,
                        id_column_gdf=None, time_column_gdf=0)
 
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0time_in_steps-1257-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0time_in_steps-1257-0.gdf')
         r = NestIO(filenames=filename)
         r.read_spiketrain(t_start=400. * pq.ms, t_stop=500. * pq.ms,
                           time_unit=pq.CompoundUnit('0.1*ms'), lazy=False,
@@ -361,20 +291,14 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
                        time_unit=pq.CompoundUnit('0.1*ms'), lazy=False,
                        id_column_gdf=None, time_column_gdf=0)
 
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         r.read_spiketrain(gdf_id=1, t_start=400. * pq.ms, t_stop=500. * pq.ms,
                           lazy=False, id_column_gdf=0, time_column_gdf=1)
         r.read_segment(gid_list=[1], t_start=400. * pq.ms, t_stop=500. * pq.ms,
                        lazy=False, id_column_gdf=0, time_column_gdf=1)
 
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time_in_steps-1258-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time_in_steps-1258-0.gdf')
         r = NestIO(filenames=filename)
         r.read_spiketrain(gdf_id=1, t_start=400. * pq.ms, t_stop=500. * pq.ms,
                           time_unit=pq.CompoundUnit('0.1*ms'), lazy=False,
@@ -388,10 +312,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         Tests if spike times are actually stored as integers if they are stored
         in time steps in the file.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0time_in_steps-1257-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0time_in_steps-1257-0.gdf')
         r = NestIO(filenames=filename)
         st = r.read_spiketrain(gdf_id=None, t_start=400. * pq.ms,
                                t_stop=500. * pq.ms,
@@ -405,10 +326,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         sts = seg.spiketrains
         self.assertTrue(all([st.magnitude.dtype == np.int32 for st in sts]))
 
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time_in_steps-1258-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time_in_steps-1258-0.gdf')
         r = NestIO(
             filenames=filename)
         st = r.read_spiketrain(gdf_id=1, t_start=400. * pq.ms,
@@ -428,30 +346,24 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         Tests if spike times are stored as floats if they
         are stored as floats in the file.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         st = r.read_spiketrain(gdf_id=1, t_start=400. * pq.ms,
                                t_stop=500. * pq.ms,
                                lazy=False, id_column=0, time_column=1)
-        self.assertTrue(st.magnitude.dtype == np.float)
+        self.assertTrue(st.magnitude.dtype == float)
         seg = r.read_segment(gid_list=[1], t_start=400. * pq.ms,
                              t_stop=500. * pq.ms,
                              lazy=False, id_column_gdf=0, time_column_gdf=1)
         sts = seg.spiketrains
-        self.assertTrue(all([s.magnitude.dtype == np.float for s in sts]))
+        self.assertTrue(all([s.magnitude.dtype == np.float_ for s in sts]))
 
     def test_values(self):
         """
         Tests if the routine loads the correct numbers from the file.
         """
         id_to_test = 1
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         seg = r.read_segment(gid_list=[id_to_test],
                              t_start=400. * pq.ms,
@@ -468,10 +380,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         """
         Tests if spiketrains are correctly stored in a segment.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
 
         id_list_to_test = range(1, 10)
@@ -490,10 +399,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         """
         Tests if spiketrains can be retrieved by specifying a range of GDF IDs.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
 
         seg = r.read_segment(gid_list=(10, 39), t_start=400. * pq.ms,
@@ -506,10 +412,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         Tests if error is thrown correctly, when second entry is smaller than
         the first one of the range.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
 
         seg = r.read_segment(gid_list=(10, 10), t_start=400. * pq.ms,
@@ -525,10 +428,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         """
         Tests if correct annotation is added when reading a spike train.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         ID = 7
         st = r.read_spiketrain(gdf_id=ID, t_start=400. * pq.ms,
@@ -539,10 +439,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         """
         Tests if correct annotation is added when reading a segment.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         IDs = (5, 11)
         sts = r.read_segment(gid_list=(5, 11), t_start=400. * pq.ms,
@@ -554,10 +451,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         """
         Tests if custom annotation is correctly added.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         st = r.read_spiketrain(gdf_id=0, t_start=400. * pq.ms,
                                t_stop=500. * pq.ms,
@@ -573,10 +467,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         - User does not specify neuron IDs although the file contains IDs.
         - User does not make any specifications.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         with self.assertRaises(ValueError):
             r.read_segment(t_start=400. * pq.ms, t_stop=500. * pq.ms,
@@ -589,10 +480,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         """
         Tests if the t_start and t_stop arguments are correctly processed.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
 
         t_stop_targ = 490. * pq.ms
@@ -613,10 +501,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         """
         Tests if undefined t_start, i.e., t_start=None raises error.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         with self.assertRaises(ValueError):
             r.read_spiketrain(gdf_id=1, t_stop=500. * pq.ms, lazy=False,
@@ -629,10 +514,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         """
         Tests if undefined t_stop, i.e., t_stop=None raises error.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         with self.assertRaises(ValueError):
             r.read_spiketrain(gdf_id=1, t_start=400. * pq.ms, lazy=False,
@@ -646,10 +528,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         Tests if ill-defined gdf_id in read_spiketrain (i.e., None, list, or
         empty list) raises error.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         with self.assertRaises(ValueError):
             r.read_spiketrain(gdf_id=[], t_start=400. * pq.ms,
@@ -665,10 +544,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         Tests if read_segment makes sure that only non-zero spike trains are
         returned.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         seg = r.read_segment(gid_list=[], t_start=400.4 * pq.ms,
                              t_stop=400.5 * pq.ms)
@@ -680,10 +556,7 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
         Tests if read_spiketrain returns an empty SpikeTrain if no spikes are in
         time range.
         """
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-1256-0.gdf',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-1256-0.gdf')
         r = NestIO(filenames=filename)
         st = r.read_spiketrain(gdf_id=0, t_start=400. * pq.ms,
                                t_stop=410. * pq.ms)
@@ -692,21 +565,20 @@ class TestNestIO_Spiketrains(BaseTestIO, unittest.TestCase):
 
 class TestNestIO_multiple_signal_types(BaseTestIO, unittest.TestCase):
     ioclass = NestIO
-    files_to_test = []
-    files_to_download = ['0gid-1time-2gex-3Vm-1261-0.dat',
-                         '0gid-1time_in_steps-1258-0.gdf']
+    entities_to_test = []
+    entities_to_download = [
+        'nest'
+    ]
 
     def test_read_analogsignal_and_spiketrain(self):
         """
         Test if spiketrains and analogsignals can be read simultaneously
         using read_segment
         """
-        files = ['0gid-1time-2gex-3Vm-1261-0.dat',
-                 '0gid-1time_in_steps-1258-0.gdf']
-        filenames = [get_test_file_full_path(ioclass=NestIO, filename=file,
-                                             directory=self.local_test_dir,
-                                             clean=False)
-                     for file in files]
+        files = ['nest/0gid-1time-2gex-3Vm-1261-0.dat',
+                 'nest/0gid-1time_in_steps-1258-0.gdf']
+        filenames = [self.get_local_path(e) for e in files]
+
         r = NestIO(filenames=filenames)
         seg = r.read_segment(gid_list=[], t_start=400 * pq.ms,
                              t_stop=600 * pq.ms,
@@ -719,14 +591,15 @@ class TestNestIO_multiple_signal_types(BaseTestIO, unittest.TestCase):
 
 class TestColumnIO(BaseTestIO, unittest.TestCase):
     ioclass = NestIO
-    files_to_download = ['0gid-1time-2Vm-3gex-4gin-1260-0.dat']
+    entities_to_test = []
+    entities_to_download = [
+        'nest'
+    ]
+
 
     def setUp(self):
         BaseTestIO.setUp(self)
-        filename = get_test_file_full_path(
-            ioclass=NestIO,
-            filename='0gid-1time-2Vm-3gex-4gin-1260-0.dat',
-            directory=self.local_test_dir, clean=False)
+        filename = self.get_local_path('nest/0gid-1time-2Vm-3gex-4gin-1260-0.dat')
         self.testIO = ColumnIO(filename=filename)
 
     def test_no_arguments(self):
