@@ -17,6 +17,9 @@ from neo.test.iotest.common_io_test import BaseTestIO
 from neo.core import AnalogSignal, SpikeTrain, Event, Epoch, IrregularlySampledSignal, Segment, \
     Block
 
+from neo.rawio.examplerawio import ExampleRawIO
+from neo.io.proxyobjects import (AnalogSignalProxy, SpikeTrainProxy, EventProxy, EpochProxy)
+
 try:
     import pynwb
     from neo.io.nwbio import NWBIO
@@ -250,6 +253,62 @@ class TestNWBIO(BaseTestIO, unittest.TestCase):
 
         os.remove(test_file_name)
 
+    def test_write_proxy_objects(self):
+        test_file_name = self.local_test_dir / "test_round_trip_with_annotations.nwb"
+
+        # generate dummy IO as basis for ProxyObjects
+        self.proxy_reader = ExampleRawIO(filename='my_filename.fake')
+        self.proxy_reader.parse_header()
+
+        # generate test structure with proxy objects
+        original_block = Block(name='myblock', session_start_time=datetime.now().astimezone(),
+                               session_description=str(test_file_name),
+                               identifier=str(test_file_name))
+        seg = Segment(name='mysegment')
+        original_block.segments.append(seg)
+
+        # create proxy objects
+        proxy_anasig = AnalogSignalProxy(rawio=self.proxy_reader, stream_index=0,
+                                         inner_stream_channels=None, block_index=0, seg_index=0,)
+        proxy_anasig.segment = seg
+        seg.analogsignals.append(proxy_anasig)
+
+        proxy_sptr = SpikeTrainProxy(rawio=self.proxy_reader, spike_channel_index=0, block_index=0,
+                                     seg_index=0)
+        proxy_sptr.segment = seg
+        seg.spiketrains.append(proxy_sptr)
+
+        proxy_event = EventProxy(rawio=self.proxy_reader, event_channel_index=0, block_index=0,
+                                 seg_index=0)
+        proxy_event.segment = seg
+        seg.events.append(proxy_event)
+
+        proxy_epoch = EpochProxy(rawio=self.proxy_reader, event_channel_index=1, block_index=0,
+                                 seg_index=0)
+        proxy_epoch.segment = seg
+        seg.epochs.append(proxy_epoch)
+
+        original_block.create_relationship()
+
+        iow = NWBIO(filename=test_file_name, mode='w')
+
+        # writing data via proxyobjects
+        iow.write_all_blocks([original_block])
+
+        # checking written data
+        ior = NWBIO(filename=test_file_name, mode='r')
+        retrieved_block = ior.read_all_blocks()[0]
+
+        for original_segment, retrieved_segment in zip(original_block.segments,
+                                                       retrieved_block.segments):
+            assert_array_equal(original_segment.analogsignals[0].load().magnitude,
+                               retrieved_segment.analogsignals[0].magnitude)
+            assert_array_equal(original_segment.spiketrains[0].load().magnitude,
+                               retrieved_segment.spiketrains[0].magnitude)
+            assert_array_equal(original_segment.events[0].load().magnitude,
+                               retrieved_segment.events[0].magnitude)
+            assert_array_equal(original_segment.epochs[0].load().magnitude,
+                               retrieved_segment.epochs[0].magnitude)
 
 if __name__ == "__main__":
     if HAVE_PYNWB:
