@@ -13,12 +13,8 @@ from neo.test.rawiotest.test_openephysrawio import TestOpenEphysRawIO
 
 class TestOpenEphysIO(BaseTestIO, unittest.TestCase, ):
     ioclass = OpenEphysIO
-    files_to_test = ['OpenEphys_SampleData_1',
-        # 'OpenEphys_SampleData_2_(multiple_starts)',  # This not implemented this raise error
-        # 'OpenEphys_SampleData_3',
-                     ]
-
-    files_to_download = TestOpenEphysRawIO.files_to_download
+    entities_to_download = TestOpenEphysRawIO.entities_to_download
+    entities_to_test = TestOpenEphysRawIO.entities_to_test
 
 
 if __name__ == "__main__":
