@@ -10,8 +10,12 @@ from neo.test.iotest.common_io_test import BaseTestIO
 
 class TestRawBinarySignalIO(BaseTestIO, unittest.TestCase, ):
     ioclass = RawBinarySignalIO
-    files_to_test = ['File_rawbinary_10kHz_2channels_16bit.raw']
-    files_to_download = files_to_test
+    entities_to_download = [
+        'rawbinarysignal'
+    ]
+    entities_to_test = [
+        'rawbinarysignal/File_rawbinary_10kHz_2channels_16bit.raw'
+    ]
 
     # Skip  this test because there are not mechanisim
     # in neo.tests.iotests to set parameters for the ioclass
