@@ -6,8 +6,12 @@ from neo.test.iotest.common_io_test import BaseTestIO
 
 class TestRawMcsIO(BaseTestIO, unittest.TestCase, ):
     ioclass = RawMCSIO
-    files_to_test = ['raw_mcs_with_header_1.raw']
-    files_to_download = files_to_test
+    entities_to_download = [
+        'rawmcs'
+    ]
+    entities_to_test = [
+        'rawmcs/raw_mcs_with_header_1.raw'
+    ]
 
 
 if __name__ == "__main__":
