@@ -39,9 +39,8 @@ class TestNeuralynxRawIO(BaseTestRawIO, unittest.TestCase, ):
         # test values here from direct inspection of .ncs files
         self.assertEqual(rawio._nb_segment, 1)
         self.assertListEqual(rawio._timestamp_limits, [(0, 192000)])
-        self.assertEqual(rawio._sigs_length[0], 4608)
-        self.assertEqual(rawio._sigs_t_start[0], 0)
-        self.assertEqual(rawio._sigs_t_stop[0], 0.192)
+        self.assertEqual(rawio._sigs_length[0][('unknown', '1')], 4608)
+        self.assertListEqual(rawio._signal_limits, [(0, 0.192)])
         self.assertEqual(len(rawio._sigs_memmaps), 1)
 
         # Test Cheetah 4.0.2, which is PRE4 type with frequency in header and
@@ -51,10 +50,10 @@ class TestNeuralynxRawIO(BaseTestRawIO, unittest.TestCase, ):
         rawio.parse_header()
         # test values here from direct inspection of .ncs files
         self.assertEqual(rawio._nb_segment, 1)
+        self.assertEqual(rawio.signal_streams_count(), 1)
         self.assertListEqual(rawio._timestamp_limits, [(266982936, 267162136)])
-        self.assertEqual(rawio._sigs_length[0], 5120)
-        self.assertEqual(rawio._sigs_t_start[0], 266.982936)
-        self.assertEqual(rawio._sigs_t_stop[0], 267.162136)
+        self.assertEqual(rawio._sigs_length[0][('unknown', '13')], 5120)
+        self.assertListEqual(rawio._signal_limits, [(266.982936, 267.162136)])
         self.assertEqual(len(rawio._sigs_memmaps), 1)
 
         # Test Cheetah 5.5.1, which is DigitalLynxSX and has two blocks of records
@@ -63,11 +62,15 @@ class TestNeuralynxRawIO(BaseTestRawIO, unittest.TestCase, ):
         rawio.parse_header()
         # test values here from direct inspection of .ncs files
         self.assertEqual(rawio._nb_segment, 2)
+        self.assertEqual(rawio.signal_streams_count(), 1)
         self.assertListEqual(rawio._timestamp_limits, [(26122557633, 26162525633),
                                                        (26366360633, 26379704633)])
-        self.assertListEqual(rawio._sigs_length, [1278976, 427008])
-        self.assertListEqual(rawio._sigs_t_stop, [26162.525633, 26379.704633])
-        self.assertListEqual(rawio._sigs_t_start, [26122.557633, 26366.360633])
+        self.assertDictEqual(rawio._sigs_length[0],
+                             {('Tet3a', '8'): 1278976, ('Tet3b', '9'): 1278976})
+        self.assertDictEqual(rawio._sigs_length[1],
+                             {('Tet3a', '8'): 427008, ('Tet3b', '9'): 427008})
+        self.assertListEqual(rawio._signal_limits, [(26122.557633, 26162.525633),
+                                                    (26366.360633, 26379.704633)])
         self.assertEqual(len(rawio._sigs_memmaps), 2)  # check only that there are 2 memmaps
 
         # Test Cheetah 6.3.2, the incomplete_blocks test. This is a DigitalLynxSX with
@@ -77,13 +80,33 @@ class TestNeuralynxRawIO(BaseTestRawIO, unittest.TestCase, ):
         # test values here from direct inspection of .ncs file, except for 3rd block
         # t_stop, which is extended due to events past the last block of ncs records.
         self.assertEqual(rawio._nb_segment, 3)
+        self.assertEqual(rawio.signal_streams_count(), 1)
         self.assertListEqual(rawio._timestamp_limits, [(8408806811, 8427831990),
                                                        (8427832053, 8487768498),
                                                        (8487768561, 8515816549)])
-        self.assertListEqual(rawio._sigs_length, [608806, 1917967, 897536])
-        self.assertListEqual(rawio._sigs_t_stop, [8427.831990, 8487.768498, 8515.816549])
-        self.assertListEqual(rawio._sigs_t_start, [8408.806811, 8427.832053, 8487.768561])
-        self.assertEqual(len(rawio._sigs_memmaps), 3)  # check only that there are 3 memmaps
+        self.assertDictEqual(rawio._sigs_length[0], {('CSC1', '48'): 608806})
+        self.assertDictEqual(rawio._sigs_length[1], {('CSC1', '48'): 1917967})
+        self.assertDictEqual(rawio._sigs_length[2], {('CSC1', '48'): 897536})
+        self.assertListEqual(rawio._signal_limits, [(8408.806811, 8427.831990),
+                                                  (8427.832053, 8487.768498),
+                                                  (8487.768561, 8515.816549)])
+        self.assertEqual(len(rawio._sigs_memmaps), 3)  # check that there are only 3 memmaps
+
+        # Test Cheetah 6.4.1, with different sampling rates across ncs files.
+        rawio = NeuralynxRawIO(self.get_local_path('neuralynx/Cheetah_v6.4.1dev/original_data'))
+        rawio.parse_header()
+
+        self.assertEqual(rawio._nb_segment, 1)
+        seg_idx = 0
+
+        self.assertEqual(rawio.signal_streams_count(), 3)
+        self.assertListEqual(rawio._timestamp_limits, [(1614363777825263, 1614363778481169)])
+        self.assertDictEqual(rawio._sigs_length[seg_idx], {('CSC1', '26'): 15872,
+                                                           ('LFP4', '41'): 1024,
+                                                           ('WE1', '33'): 512})
+        self.assertListEqual(rawio._signal_limits, [(1614363777.825263, 1614363778.481169)])
+        # check that there are only 3 memmaps
+        self.assertEqual(len(rawio._sigs_memmaps[seg_idx]), 3)
 
     def test_single_file_mode(self):
         """
